"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.similarTo = exports.contains = exports.matches = exports.or = void 0;
const string_similarity_1 = require("string-similarity");
exports.or = (...whens) => ({
    check: (transcript) => whens.some((when) => when.check(transcript)),
    describe: () => `either:\n${whens.map((w) => w.describe()).join("\n")}`,
});
exports.matches = (pattern) => ({
    check: (transcript) => pattern.test(transcript),
    describe: () => `matches regex pattern ${pattern}`,
});
exports.contains = (partial) => ({
    check: (transcript) => transcript.includes(partial),
    describe: () => `contains ${partial}`,
});
/**
 * Compares two strings to determine if they're similar.
 * See https://www.npmjs.com/package/string-similarity#api to read how similarity is calculated.
 *
 * @param {string} similarText Text that is compared to the transcript for similarity
 * @param {number} similarityThreshold The degree of similarity is measured in a fraction between 0 and 1.
 * 0 indicates completely different strings, 1 indicates identical strings. The comparison is case-sensitive.
 * @return {boolean} True if strings are considered similar, else false
 */
exports.similarTo = (similarText, similarityThreshold = 0.8) => ({
    check: (transcript) => string_similarity_1.compareTwoStrings(similarText, transcript) >= similarityThreshold,
    describe: () => `similar to "${similarText}"`,
});
