"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MediaStreamRecorder = void 0;
const fs_1 = require("fs");
const path = __importStar(require("path"));
const TwilioCall_1 = require("./TwilioCall");
const twilio_1 = require("../twilio");
class MediaStreamRecorder {
    constructor(connection, config, test) {
        this.connection = connection;
        this.config = config;
        this.test = test;
        this.onMessageFunc = this.processMessage.bind(this);
        this.onCloseFunc = this.close.bind(this);
        connection.on(TwilioCall_1.WebSocketEvents.Message, this.onMessageFunc);
        connection.on(TwilioCall_1.WebSocketEvents.Close, this.onCloseFunc);
    }
    processMessage(message) {
        const data = JSON.parse(message);
        switch (data.event) {
            case twilio_1.TwilioConnectionEvents.MediaStreamStart:
                this.createFile(data);
                break;
            case twilio_1.TwilioConnectionEvents.Media:
                this.writeToFile(Buffer.from(data.media.payload, "base64"));
                break;
            case twilio_1.TwilioConnectionEvents.CallEnded:
                this.close();
                console.log("Stopped recording");
                break;
        }
    }
    createFilename(event) {
        const call = twilio_1.callParameterSerializer.extractParameters(event);
        let filename;
        if (typeof this.config.filename === "string") {
            filename = this.config.filename;
        }
        else if (typeof this.config.filename === "function") {
            filename = this.config.filename({
                sid: event.streamSid,
                phoneNumbers: call,
            }, this.test);
        }
        else {
            filename = `${Date.now()}-${event.streamSid}`;
        }
        return `${filename}.${MediaStreamRecorder.FILE_EXT}`;
    }
    createFile(event) {
        const filename = this.createFilename(event);
        const filepath = path.join(this.config.outputPath, filename);
        console.log(`Recording inbound stream to '${filepath}'`);
        fs_1.mkdirSync(this.config.outputPath, { recursive: true });
        this.writeStream = fs_1.createWriteStream(filepath);
    }
    writeToFile(data) {
        this.writeStream.write(data);
    }
    close() {
        this.connection.off(TwilioCall_1.WebSocketEvents.Message, this.onMessageFunc);
        this.connection.off(TwilioCall_1.WebSocketEvents.Close, this.onCloseFunc);
        this.writeStream.close();
        this.writeStream = null;
    }
}
exports.MediaStreamRecorder = MediaStreamRecorder;
MediaStreamRecorder.FILE_EXT = "wav";
