/// <reference types="node" />
import { EventEmitter } from "events";
import { TranscriptCondition } from "../conditions/TranscriptCondition";
import { Call } from "./ordered";
export interface TestSubject {
    from: string;
    to: string;
}
export interface TestResult {
    matchedCondition?: TranscriptCondition;
    result: "continue" | "fail" | "pass";
}
export interface TestContainer {
    test(transcript: string, call: Call): TestResult;
}
export interface IvrTest {
    name: string;
    test: TestContainer;
}
export interface TestFailed {
    test: IvrTest;
    transcription: string;
}
export interface TestPassed {
    test: IvrTest;
}
export interface TestConditionMet {
    test: IvrTest;
    transcription: string;
    condition: TranscriptCondition;
}
/**
 * Conditions have to have been met in sequence
 */
export declare class TestHandler extends EventEmitter {
    private readonly call;
    private readonly transcriptionHandler;
    private readonly ivrTest;
    private static readonly TRANSCRIPTION_EVENT;
    private static readonly TEST_FAILED_EVENT;
    private static readonly TEST_PASSED_EVENT;
    private static readonly TEST_CONDITION_MET_EVENT;
    constructor(call: Call, transcriptionHandler: EventEmitter, ivrTest: IvrTest);
    private processTranscript;
    private notifyOfFailedTest;
    private notifyOfPassedTest;
    private notifyOfConditionBeingMet;
}
