"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestHandler = void 0;
const events_1 = require("events");
/**
 * Conditions have to have been met in sequence
 */
class TestHandler extends events_1.EventEmitter {
    constructor(call, transcriptionHandler, ivrTest) {
        super();
        this.call = call;
        this.transcriptionHandler = transcriptionHandler;
        this.ivrTest = ivrTest;
        transcriptionHandler.on(TestHandler.TRANSCRIPTION_EVENT, this.processTranscript.bind(this));
    }
    processTranscript({ transcription }) {
        const testOutcome = this.ivrTest.test.test(transcription, this.call);
        switch (testOutcome.result) {
            case "continue":
                if (testOutcome.matchedCondition) {
                    this.notifyOfConditionBeingMet(transcription, testOutcome.matchedCondition);
                }
                return;
            case "pass":
                if (testOutcome.matchedCondition) {
                    this.notifyOfConditionBeingMet(transcription, testOutcome.matchedCondition);
                }
                this.notifyOfPassedTest();
                return;
            case "fail":
                this.notifyOfFailedTest(transcription);
                return;
            default:
                return;
        }
    }
    notifyOfFailedTest(transcription) {
        const event = { transcription, test: this.ivrTest };
        this.emit(TestHandler.TEST_FAILED_EVENT, event);
    }
    notifyOfPassedTest() {
        const event = {
            test: this.ivrTest,
        };
        this.emit(TestHandler.TEST_PASSED_EVENT, event);
    }
    notifyOfConditionBeingMet(transcription, condition) {
        const event = {
            test: this.ivrTest,
            transcription,
            condition,
        };
        this.emit(TestHandler.TEST_CONDITION_MET_EVENT, event);
    }
}
exports.TestHandler = TestHandler;
TestHandler.TRANSCRIPTION_EVENT = "transcription";
TestHandler.TEST_FAILED_EVENT = "TestFailed";
TestHandler.TEST_PASSED_EVENT = "TestPassed";
TestHandler.TEST_CONDITION_MET_EVENT = "ConditionMet";
