"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TranscriptionHandler = void 0;
const events_1 = require("events");
const TwilioCall_1 = require("./TwilioCall");
const twilio_1 = require("../twilio");
class TranscriptionHandler extends events_1.EventEmitter {
    constructor(connection, transcriber) {
        super();
        this.connection = connection;
        this.transcriber = transcriber;
        connection.on(TwilioCall_1.WebSocketEvents.Message, this.processMessage.bind(this));
        connection.on(TwilioCall_1.WebSocketEvents.Close, this.close.bind(this));
        transcriber.on(TranscriptionHandler.TRANSCRIPTION_EVENT, this.processTranscript.bind(this));
    }
    processTranscript(event) {
        this.emit(TranscriptionHandler.TRANSCRIPTION_EVENT, event);
    }
    processMessage(message) {
        const data = JSON.parse(message);
        switch (data.event) {
            case twilio_1.TwilioConnectionEvents.Media:
                this.transcriber.transcribe(data.media.payload);
                break;
            case twilio_1.TwilioConnectionEvents.CallEnded:
                this.close();
                break;
        }
    }
    close() {
        this.connection.off(TwilioCall_1.WebSocketEvents.Message, this.processMessage);
        this.connection.off(twilio_1.TwilioConnectionEvents.CallEnded, this.close);
        this.transcriber.close();
    }
}
exports.TranscriptionHandler = TranscriptionHandler;
TranscriptionHandler.TRANSCRIPTION_EVENT = "transcription";
