"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
};
var _processMessageReference, _streamSid;
Object.defineProperty(exports, "__esModule", { value: true });
exports.TwilioCall = exports.WebSocketEvents = void 0;
const twilio_1 = require("../twilio");
var WebSocketEvents;
(function (WebSocketEvents) {
    // eslint-disable-next-line no-unused-vars
    WebSocketEvents["Message"] = "message";
    // eslint-disable-next-line no-unused-vars
    WebSocketEvents["Close"] = "close";
})(WebSocketEvents = exports.WebSocketEvents || (exports.WebSocketEvents = {}));
class TwilioCall {
    constructor(connection, dtmfGenerator) {
        this.connection = connection;
        this.dtmfGenerator = dtmfGenerator;
        _processMessageReference.set(this, void 0);
        _streamSid.set(this, void 0);
        __classPrivateFieldSet(this, _processMessageReference, this.processMessage.bind(this));
        connection.on(WebSocketEvents.Message, __classPrivateFieldGet(this, _processMessageReference));
    }
    processMessage(message) {
        const data = JSON.parse(message);
        // Add debug output for all from https://www.twilio.com/blog/multiple-twilio-streams-javascript
        if (data.event === twilio_1.TwilioConnectionEvents.MediaStreamStart) {
            __classPrivateFieldSet(this, _streamSid, data.streamSid);
            this.connection.off(WebSocketEvents.Message, __classPrivateFieldGet(this, _processMessageReference));
        }
    }
    sendDtmfTone(dtmfSequence) {
        this.sendMedia(this.dtmfGenerator.generate(dtmfSequence));
    }
    sendMedia(payload) {
        if (!__classPrivateFieldGet(this, _streamSid)) {
            throw new Error("Stream SID must be set before media can be sent");
        }
        const message = {
            event: twilio_1.TwilioConnectionEvents.Media,
            streamSid: __classPrivateFieldGet(this, _streamSid),
            media: {
                payload: payload.toString("base64"),
            },
        };
        this.connection.send(JSON.stringify(message));
    }
}
exports.TwilioCall = TwilioCall;
_processMessageReference = new WeakMap(), _streamSid = new WeakMap();
