"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const matchers_1 = require("../conditions/matchers");
const actions_1 = require("../conditions/actions");
const ordered_1 = require("./ordered");
describe("ordered conditions", () => {
    test("test passes if no conditions provided", () => {
        const dtmfGenerator = {
            sendDtmfTone: jest.fn(),
            sendMedia: jest.fn(),
        };
        const orderedConditions = ordered_1.ordered([]);
        const testOutcome = orderedConditions.test("Hello", dtmfGenerator);
        expect(dtmfGenerator.sendDtmfTone).not.toHaveBeenCalled();
        expect(testOutcome).toMatchObject({
            result: "pass",
        });
    });
    test("all match and test passes for last one", () => {
        const conditions = [
            {
                when: matchers_1.contains("Hello"),
                then: actions_1.press("1"),
            },
            {
                when: matchers_1.contains("Jane"),
                then: actions_1.press("2"),
            },
            {
                when: matchers_1.contains("Austen"),
                then: actions_1.press("3"),
            },
        ];
        const call = {
            sendDtmfTone: jest.fn(),
            sendMedia: jest.fn(),
        };
        const orderedConditions = ordered_1.ordered(conditions);
        const testOutcome1 = orderedConditions.test("Hello", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome1).toMatchObject({
            matchedCondition: conditions[0],
            result: "continue",
        });
        const testOutcome2 = orderedConditions.test("Jane", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome2).toMatchObject({
            matchedCondition: conditions[1],
            result: "continue",
        });
        const testOutcome3 = orderedConditions.test("Austen", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome3).toMatchObject({
            matchedCondition: conditions[2],
            result: "pass",
        });
    });
    test("test failed when second condition doesn't match", () => {
        const conditions = [
            {
                when: matchers_1.contains("Hello"),
                then: actions_1.press("1"),
            },
            {
                when: matchers_1.contains("Jane"),
                then: actions_1.press("2"),
            },
        ];
        const call = {
            sendDtmfTone: jest.fn(),
            sendMedia: jest.fn(),
        };
        const orderedConditions = ordered_1.ordered(conditions);
        const testOutcome1 = orderedConditions.test("Hello", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome1).toMatchObject({
            matchedCondition: conditions[0],
            result: "continue",
        });
        const testOutcome2 = orderedConditions.test("Darcy", call);
        expect(call.sendDtmfTone).toHaveBeenCalled();
        expect(testOutcome2).toMatchObject({
            result: "fail",
        });
    });
});
