"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const wait_for_expect_1 = __importDefault(require("wait-for-expect"));
const server_1 = require("../server");
const StopWhenAllTestsComplete_1 = require("./StopWhenAllTestsComplete");
const get_port_1 = __importDefault(require("get-port"));
const eventEmitter_1 = require("./events/eventEmitter");
describe("server", () => {
    let server;
    let serverConfig;
    beforeEach(async () => {
        serverConfig = { localServerPort: await get_port_1.default() };
    });
    afterAll((done) => {
        if (server) {
            server.wss.close(done);
        }
    });
    test("server is closed when test succeeds", async () => {
        const stopWhenAllTestsComplete = new StopWhenAllTestsComplete_1.StopWhenAllTestsComplete();
        const serverClosedCallback = jest.fn();
        const emitter = eventEmitter_1.createLifecycleEventEmitter();
        server = await server_1.startServerListening(serverConfig, [], emitter);
        server.wss.on("close", serverClosedCallback);
        stopWhenAllTestsComplete.initialise(emitter);
        emitter.emit("callHandlingServerStarted", { server: server.wss });
        emitter.emit("ivrTestPassed", { test: undefined });
        await wait_for_expect_1.default(() => {
            expect(serverClosedCallback).toBeCalled();
        });
    });
    test("server is closed when test fails", async () => {
        const stopWhenAllTestsComplete = new StopWhenAllTestsComplete_1.StopWhenAllTestsComplete();
        const serverClosedCallback = jest.fn();
        const emitter = eventEmitter_1.createLifecycleEventEmitter();
        server = await server_1.startServerListening(serverConfig, [], emitter);
        server.wss.on("close", serverClosedCallback);
        stopWhenAllTestsComplete.initialise(emitter);
        emitter.emit("callHandlingServerStarted", { server: server.wss });
        emitter.emit("ivrTestFailed", { test: undefined, transcription: "" });
        await wait_for_expect_1.default(() => {
            expect(serverClosedCallback).toBeCalled();
        });
    });
});
