"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.consoleLogger = void 0;
const chalk_1 = __importDefault(require("chalk"));
const log_symbols_1 = __importDefault(require("log-symbols"));
const ivrTestPassed = (emitter) => emitter.on("ivrTestPassed", (event) => console.log(log_symbols_1.default.success, chalk_1.default.green(`Test Complete: ${event.test.name}`)));
const ivrTestFailed = (emitter) => emitter.on("ivrTestFailed", (event) => {
    console.log(`${chalk_1.default.bold.blue("Test -")} ${chalk_1.default.bold.blue(event.test.name)}\n`, `Them: "${event.transcription}"\n`, chalk_1.default.red("No condition matched this transcript\n"));
    console.log(log_symbols_1.default.error, chalk_1.default.bold.red(`Test Failed`));
});
const callConnected = (emitter) => emitter.on("callConnected", () => console.log("Call connected to the server"));
const callAssignedTest = (emitter) => emitter.on("callAssignedTest", (event) => console.log(`Call using test '${event.test.name}'`));
const callHandlingServerStarted = (emitter) => emitter.on("callHandlingServerStarted", ({ server }) => {
    const { port } = server.address();
    console.log(`Server is listening on ${port} for the stream for the call`);
});
const callHandlingServerStopped = (emitter) => emitter.on("callHandlingServerStopped", () => console.log("The server has closed"));
const callHandlingServerErrored = (emitter) => emitter.on("callHandlingServerErrored", (event) => console.error("Server experienced an error", event.error.message));
const callRequested = (emitter) => emitter.on("callRequested", (event) => console.log(`Telling Twilio call ${event.call.to} (${event.current} of ${event.total})`));
const callRequestErrored = (emitter) => emitter.on("callRequestErrored", (event) => console.error("Twilio failed to make the call...", event.error.message));
const ivrTestConditionMet = (emitter) => emitter.on("ivrTestConditionMet", (event) => console.log(`${chalk_1.default.bold.blue("Test -")} ${chalk_1.default.bold.blue(event.test.name)}\n`, `Them: "${event.transcription}"\n`, `You: ${event.condition.then.describe()}\n`));
exports.consoleLogger = {
    initialise(eventEmitter) {
        ivrTestPassed(eventEmitter);
        ivrTestFailed(eventEmitter);
        callConnected(eventEmitter);
        callAssignedTest(eventEmitter);
        callHandlingServerStarted(eventEmitter);
        callHandlingServerStopped(eventEmitter);
        callHandlingServerErrored(eventEmitter);
        callRequested(eventEmitter);
        callRequestErrored(eventEmitter);
        ivrTestConditionMet(eventEmitter);
    },
};
