"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMockTranscriber = exports.createMockDtmfGenerator = exports.waitForConnection = void 0;
const ws_1 = __importDefault(require("ws"));
const wait_for_expect_1 = __importDefault(require("wait-for-expect"));
const server_1 = require("./server");
const events_1 = require("events");
const ordered_1 = require("./handlers/ordered");
const get_port_1 = __importDefault(require("get-port"));
exports.waitForConnection = async (ws) => new Promise((resolve) => ws.on("open", resolve));
exports.createMockDtmfGenerator = () => ({ generate: jest.fn() });
class TranscriberTestDouble extends events_1.EventEmitter {
    close() { }
    transcribe(payload) { }
    produceTranscriptionEvent(transcription) {
        const event = { transcription };
        this.emit("transcription", event);
    }
}
exports.createMockTranscriber = () => ({
    addListener: jest.fn(),
    eventNames: jest.fn(),
    getMaxListeners: jest.fn(),
    listenerCount: jest.fn(),
    listeners: jest.fn(),
    off: jest.fn(),
    once: jest.fn(),
    prependListener: jest.fn(),
    prependOnceListener: jest.fn(),
    rawListeners: jest.fn(),
    removeAllListeners: jest.fn(),
    removeListener: jest.fn(),
    setMaxListeners: jest.fn(),
    transcribe: jest.fn(),
    emit: jest.fn(),
    on: jest.fn(),
    close: jest.fn(),
});
const fiveSeconds = 5 * 1000;
jest.setTimeout(fiveSeconds);
describe("server", () => {
    let server;
    let ws;
    afterAll((done) => {
        if (server) {
            server.wss.close(done);
        }
    });
    test("recipient's audio transcribed for test", async () => {
        const transcriber = new TranscriberTestDouble();
        const config = {
            localServerPort: await get_port_1.default(),
            dtmfGenerator: exports.createMockDtmfGenerator(),
            transcriber: () => transcriber,
        };
        const test = {
            name: "",
            test: ordered_1.ordered([]),
        };
        const emitter = {
            emit: jest.fn(),
            off: jest.fn(),
            on: jest.fn(),
        };
        server = await server_1.startServerListening(config, [test], emitter);
        const { port } = server.wss.address();
        ws = new ws_1.default(`ws://localhost:${port}/`);
        await exports.waitForConnection(ws);
        jest.spyOn(transcriber, "transcribe").mockImplementation(() => {
            transcriber.produceTranscriptionEvent("hello world");
        });
        const callMediaPayload = "base-64-encoded-payload";
        ws.send(JSON.stringify({
            event: "media",
            media: {
                payload: callMediaPayload,
            },
        }));
        await wait_for_expect_1.default(() => {
            expect(transcriber.transcribe).toBeCalledWith(callMediaPayload);
            expect(emitter.emit).toHaveBeenCalledWith("ivrTestPassed", expect.any(Object));
        });
    });
});
