"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.testRunner = void 0;
const twilio_1 = require("twilio");
const server_1 = require("./server");
const Config_1 = require("./Config");
const twilio_2 = require("./twilio");
const eventEmitter_1 = require("./plugins/events/eventEmitter");
const url_1 = require("url");
const createPublicStreamUrl = (config, server) => {
    const serverUrl = config.publicServerUrl || server_1.formatServerUrl(server);
    const streamUrl = new url_1.URL(serverUrl.toString());
    streamUrl.pathname = "/";
    streamUrl.protocol = "wss";
    return streamUrl;
};
const makeCall = (config, call, streamUrl) => {
    const response = new twilio_1.twiml.VoiceResponse();
    const connect = response.connect();
    const stream = connect.stream({ url: streamUrl.toString() });
    twilio_2.callParameterSerializer.addParameters(stream, call);
    return config.twilioClient.calls.create({
        twiml: response.toString(),
        ...call,
    });
};
exports.testRunner = (config) => async (call, ivrTest) => {
    config = Config_1.populateDefaults(config);
    const tests = Array.isArray(ivrTest) ? ivrTest : [ivrTest];
    const emitter = eventEmitter_1.createLifecycleEventEmitter();
    config.plugins.forEach((plugin) => plugin.initialise(emitter));
    const server = await server_1.startServerListening(config, tests, emitter);
    emitter.emit("callHandlingServerStarted", { server: server.wss });
    const callPromises = tests.map((test, index) => {
        emitter.emit("callRequested", {
            call,
            total: tests.length,
            current: index + 1,
        });
        return makeCall(config, call, createPublicStreamUrl(config, server));
    });
    return new Promise((resolve, reject) => {
        Promise.all(callPromises)
            .then(() => {
            server.wss.on("close", () => {
                emitter.emit("callHandlingServerStopped", undefined);
                resolve();
            });
            server.wss.on("error", (error) => {
                emitter.emit("callHandlingServerErrored", { error });
                reject(error);
            });
        })
            .catch((error) => {
            emitter.emit("callRequestErrored", { error });
            server.wss.close((err) => err && console.error(err));
            reject(error);
        });
    });
};
