"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, privateMap, value) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to set private field on non-instance");
    }
    privateMap.set(receiver, value);
    return value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, privateMap) {
    if (!privateMap.has(receiver)) {
        throw new TypeError("attempted to get private field on non-instance");
    }
    return privateMap.get(receiver);
};
var _config, _stream, _streamCreatedAt;
Object.defineProperty(exports, "__esModule", { value: true });
exports.mulawGoogleSpeechToText = exports.MulawGoogleSpeechToText = void 0;
const events_1 = require("events");
const speech_1 = require("@google-cloud/speech");
class MulawGoogleSpeechToText extends events_1.EventEmitter {
    constructor(speechPhrases = [], useEnhanced = true, speechClient = new speech_1.SpeechClient()) {
        super();
        this.speechPhrases = speechPhrases;
        this.useEnhanced = useEnhanced;
        this.speechClient = speechClient;
        _config.set(this, void 0);
        _stream.set(this, void 0); // TODO Type this
        _streamCreatedAt.set(this, void 0);
        __classPrivateFieldSet(this, _config, MulawGoogleSpeechToText.createConfig(speechPhrases, useEnhanced));
    }
    static createConfig(speechPhrases, useEnhanced) {
        return {
            config: {
                encoding: speech_1.protos.google.cloud.speech.v1.RecognitionConfig.AudioEncoding.MULAW,
                sampleRateHertz: 8000,
                languageCode: "en-GB",
                model: "phone_call",
                speechContexts: [{ phrases: speechPhrases }],
                useEnhanced,
            },
            interimResults: false,
            singleUtterance: false,
        };
    }
    transcribe(payload) {
        this.getStream().write(payload);
    }
    close() {
        if (__classPrivateFieldGet(this, _stream)) {
            __classPrivateFieldGet(this, _stream).destroy();
        }
    }
    newStreamRequired() {
        if (!__classPrivateFieldGet(this, _stream)) {
            return true;
        }
        else {
            const now = new Date();
            const timeSinceStreamCreated = now.valueOf() - __classPrivateFieldGet(this, _streamCreatedAt).valueOf();
            return timeSinceStreamCreated / 1000 > 60;
        }
    }
    getStream() {
        if (this.newStreamRequired()) {
            if (__classPrivateFieldGet(this, _stream)) {
                __classPrivateFieldGet(this, _stream).destroy();
            }
            __classPrivateFieldSet(this, _streamCreatedAt, new Date());
            __classPrivateFieldSet(this, _stream, this.speechClient
                .streamingRecognize(__classPrivateFieldGet(this, _config))
                .on("error", console.error)
                .on("data", (data) => {
                const result = data.results[0];
                if ((result === null || result === void 0 ? void 0 : result.alternatives[0]) !== undefined) {
                    const event = {
                        transcription: result.alternatives[0].transcript.trim(),
                    };
                    this.emit("transcription", event);
                }
            }));
        }
        return __classPrivateFieldGet(this, _stream);
    }
}
exports.MulawGoogleSpeechToText = MulawGoogleSpeechToText;
_config = new WeakMap(), _stream = new WeakMap(), _streamCreatedAt = new WeakMap();
exports.mulawGoogleSpeechToText = (speechPhrases = [], useEnhanced = true, speechClient = new speech_1.SpeechClient()) => () => new MulawGoogleSpeechToText(speechPhrases, useEnhanced, speechClient);
